@@ -1,5 +1,5 @@
 package App::SmokeBrew;
-$App::SmokeBrew::VERSION = '1.00';
+$App::SmokeBrew::VERSION = '1.02';
 #ABSTRACT: The guts of smokebrew
 
 use strict;
@@ -18,8 +18,6 @@ use Getopt::Long;
 my @mirrors = (
   'http://www.cpan.org/',
   'http://cpan.cpantesters.org/',
-  'http://cpan.hexten.net/',
-  'ftp://ftp.funet.fi/pub/CPAN/',
 );
 
 use Moose;
@@ -312,7 +310,7 @@ App::SmokeBrew - The guts of smokebrew
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -344,7 +342,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Chris Williams.
+This software is copyright (c) 2022 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
