@@ -1,5 +1,5 @@
 package App::SmokeBrew::BuildPerl;
-$App::SmokeBrew::BuildPerl::VERSION = '1.00';
+$App::SmokeBrew::BuildPerl::VERSION = '1.02';
 #ABSTRACT: build and install a particular version of Perl
 
 use strict;
@@ -26,8 +26,6 @@ with 'App::SmokeBrew::PerlVersion';
 my @mirrors = (
   'http://www.cpan.org/',
   'http://cpan.cpantesters.org/',
-  'http://cpan.hexten.net/',
-  'ftp://ftp.funet.fi/pub/CPAN/',
 );
 
 has 'builddir' => (
@@ -180,7 +178,7 @@ App::SmokeBrew::BuildPerl - build and install a particular version of Perl
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -300,7 +298,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Chris Williams.
+This software is copyright (c) 2022 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
